searchData={"items":[{"type":"module","title":"BCUtils.Banner","doc":"Provides functionality to display a startup banner.","ref":"BCUtils.Banner.html"},{"type":"function","title":"BCUtils.Banner.display_banner/1","doc":"","ref":"BCUtils.Banner.html#display_banner/1"},{"type":"module","title":"BCUtils.BitFlags","doc":"This module is used to manipulate bitwise flags.\n\n  Inspired by: [Flags in C#](https://stackoverflow.com/questions/8447/what-does-the-flags-enum-attribute-mean-in-c)\n\n  Event sourced systems often rely on flags to indicate the state of the aggregate at any given time.\n  In essence, an event sourced aggregate is a finite state machine and this state is \n  often represented as a set of flags, to be used as a shorthand for the state of the aggregate.\n\n  In this module, we define a set of functions that can be used to manipulate these flags.","ref":"BCUtils.BitFlags.html"},{"type":"function","title":"BCUtils.BitFlags.decompose/1","doc":"","ref":"BCUtils.BitFlags.html#decompose/1"},{"type":"function","title":"BCUtils.BitFlags.has?/2","doc":"Returs true if the given flag is set in the target state.\n  In other words, it returns true if the bit that corresponds to the flag is set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flag to be checked is `0b01000000` (integer: 64)\n  THEN the result is `true`\n\n  Example:\n  iex> BitFlags.has?(100, 64)\n  true","ref":"BCUtils.BitFlags.html#has?/2"},{"type":"function","title":"BCUtils.BitFlags.has_all?/2","doc":"Returns true if ALL the flags are set in the target state.\n  In other words, it returns true if ALL the bits that correspond to the flags are set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flags to be checked are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `true`\n  AND WHEN the flags to be checked are `[0b01000000, 0b00000100]` (integers: 64, 8)\n  THEN the result is `false`\n\n  Example:\n  iex> BitFlags.has_all?(100, [64, 128])\n  true\n  iex> BitFlags.has_all?(100, [64, 8])\n  false","ref":"BCUtils.BitFlags.html#has_all?/2"},{"type":"function","title":"BCUtils.BitFlags.has_any?/2","doc":"Returns true if any of the flags are set in the target state.\n  In other words, it returns true if any of the bits that correspond to the flags are set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flags to be checked are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `true`\n\n  Example:\n  iex> BitFlags.has_any?(100, [64, 128])\n  true","ref":"BCUtils.BitFlags.html#has_any?/2"},{"type":"function","title":"BCUtils.BitFlags.has_not?/2","doc":"Returns true if the given flag is NOT set in the target state.\n  In other words, it returns true if the bit that corresponds to the flag is NOT set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flag to be checked is `0b01000000` (integer: 64)\n  THEN the result is `false`\n  AND WHEN the flag to be checked is `0b00000100` (integer: 8)\n  THEN the result is `true`\n\n  Example:\n  iex> BitFlags.has_not?(100, 64)\n  false\n  iex> BitFlags.has_not?(100, 8)\n  true","ref":"BCUtils.BitFlags.html#has_not?/2"},{"type":"function","title":"BCUtils.BitFlags.highest/2","doc":"Returns the highest flag in the target state.\n  GIVEN: target_state is `0b01100100` (integer: 100)    \n  AND the flag_map is:\n      %{\n         0 => \"None\",\n         1 => \"Ready\",\n         2 => \"In Progress\",\n         4 => \"Completed\",\n         8 => \"Cancelled\",\n         16 => \"Failed\",\n         32 => \"Archived\",\n         64 => \"Ready to Archive\",\n         128 => \"Ready to Publish\",\n      }\n  THEN the result is `Ready to Archive`\n\n  Example:\n  iex> descriptions = \n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>  }\n  %{\n     0 => \"None\",\n     1 => \"Ready\",\n     2 => \"In Progress\",\n     4 => \"Completed\",\n     8 => \"Cancelled\",\n     16 => \"Failed\",\n     32 => \"Archived\",\n     64 => \"Ready to Archive\",\n     128 => \"Ready to Publish\",\n  }\n  iex> BitFlags.highest(100, descriptions)\n  \"Ready to Archive\"","ref":"BCUtils.BitFlags.html#highest/2"},{"type":"function","title":"BCUtils.BitFlags.lowest/2","doc":"Returns the lowest flag in the bit flag map.\n  GIVEN: target_state is `0b01100100` (integer: 100)\n  AND the flag_map is:\n      %{\n         0 => \"None\",\n         1 => \"Ready\",\n         2 => \"In Progress\",\n         4 => \"Completed\",\n         8 => \"Cancelled\",\n         16 => \"Failed\",\n         32 => \"Archived\",\n         64 => \"Ready to Archive\",\n         128 => \"Ready to Publish\",\n      }\n   THEN the result is `Ready`\n\n  Example:\n  iex> descriptions = \n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>  }\n  %{\n     0 => \"None\",\n     1 => \"Ready\",\n     2 => \"In Progress\",\n     4 => \"Completed\",\n     8 => \"Cancelled\",\n     16 => \"Failed\",\n     32 => \"Archived\",\n     64 => \"Ready to Archive\",\n     128 => \"Ready to Publish\",\n  }\n  iex> BitFlags.lowest(100, descriptions)\n  \"Ready\"","ref":"BCUtils.BitFlags.html#lowest/2"},{"type":"function","title":"BCUtils.BitFlags.set/2","doc":"","ref":"BCUtils.BitFlags.html#set/2"},{"type":"function","title":"Description - BCUtils.BitFlags.set/2","doc":"Returns the bitwise OR of two flags.\n  In other words, it sets the bit that corresopnds to the flag\n\n  - GIVEN: original_state is `0b00100100` (integer: 36) \n  - WHEN the flag to be set is `0b01000000` (integer: 64)\n  - THEN the result is `0b01100100` (integer: 100)","ref":"BCUtils.BitFlags.html#set/2-description"},{"type":"function","title":"Parameters - BCUtils.BitFlags.set/2","doc":"- target: the integer to be set\n  - flag: the integer to be set","ref":"BCUtils.BitFlags.html#set/2-parameters"},{"type":"function","title":"Output - BCUtils.BitFlags.set/2","doc":"The integer representation of the state after setting the flag","ref":"BCUtils.BitFlags.html#set/2-output"},{"type":"function","title":"Examples - BCUtils.BitFlags.set/2","doc":"iex> BitFlags.set(36, 64)\n  100","ref":"BCUtils.BitFlags.html#set/2-examples"},{"type":"function","title":"BCUtils.BitFlags.set_all/2","doc":"Returns the bitwise OR of multiple flags against a given state.\n  In other words, it sets the bits that corresopnds to the flags\n  GIVEN: original_state is `0b00100100` (integer: 36)\n  WHEN the flags to be set are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `0b11100100` (integer: 228)\n\n  Example:\n  iex> BitFlags.set_all(36, [64, 128])\n  228","ref":"BCUtils.BitFlags.html#set_all/2"},{"type":"function","title":"BCUtils.BitFlags.to_list/2","doc":"Returns a list of flag descriptions that are set in the target state.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  AND the flag_map is:\n     %{\n        0 => \"None\",\n        1 => \"Ready\",\n        2 => \"In Progress\",\n        4 => \"Completed\",\n        8 => \"Cancelled\",\n        16 => \"Failed\",\n        32 => \"Archived\",\n        64 => \"Ready to Archive\",\n        128 => \"Ready to Publish\",\n        256 => \"Published\",\n        512 => \"Unpublished\",\n     }\n  WHEN the target state is `0b01100100` (integer: 100)\n  THEN the result is `[\"Completed\", \"Archived\", \"Ready to Archive\"]`\n\n  Example: \n  iex> descriptions = \n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>       256 => \"Published\",\n  ...>       512 => \"Unpublished\",\n  ...>  }\n  iex> BitFlags.to_list(100, descriptions)\n  [\"Completed\", \"Archived\", \"Ready to Archive\"]","ref":"BCUtils.BitFlags.html#to_list/2"},{"type":"function","title":"BCUtils.BitFlags.to_string/2","doc":"Returns a string representation of the bit flags.\n  GIVEN: target_state is `0b01100100` (integer: 100)\n  AND the flag_map is:\n       %{\n         0 => \"None\",\n         1 => \"Ready\",\n         2 => \"In Progress\",\n         4 => \"Completed\",\n         8 => \"Cancelled\",\n         16 => \"Failed\",\n         32 => \"Archived\",\n         64 => \"Ready to Archive\",\n         128 => \"Ready to Publish\",\n      }\n  THEN the result is `\"Completed, Archived, Ready to Archive\"`\n\n  Example:\n  iex> descriptions =\n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>  }\n  iex> BitFlags.to_string(100, descriptions)\n  \"Completed, Archived, Ready to Archive\"","ref":"BCUtils.BitFlags.html#to_string/2"},{"type":"function","title":"BCUtils.BitFlags.unset/2","doc":"","ref":"BCUtils.BitFlags.html#unset/2"},{"type":"function","title":"Description - BCUtils.BitFlags.unset/2","doc":"Returns the bitwise AND of two flags.\n  In other words, it unsets the bit that corresopnds to the flag\n\n  - GIVEN: original_state is `0b01100100` (integer: 100)\n  - WHEN the flag to be unset is `0b01000000` (integer: 64)\n  - THEN the result is `0b00100100` (integer: 36)","ref":"BCUtils.BitFlags.html#unset/2-description"},{"type":"function","title":"Parameters - BCUtils.BitFlags.unset/2","doc":"- `target`: the integer representation of the state\n    - `flag`  : the integer representation of the flag","ref":"BCUtils.BitFlags.html#unset/2-parameters"},{"type":"function","title":"Output - BCUtils.BitFlags.unset/2","doc":"The integer representation of the state after unsetting the flag","ref":"BCUtils.BitFlags.html#unset/2-output"},{"type":"function","title":"Examples - BCUtils.BitFlags.unset/2","doc":"iex> BitFlags.unset(100, 64)\n    36","ref":"BCUtils.BitFlags.html#unset/2-examples"},{"type":"function","title":"BCUtils.BitFlags.unset_all/2","doc":"Returns the bitwise AND of multiple flags against a given state.\n  In other words, it unsets the bits that corresopnds to the flags\n  GIVEN: original_state is `0b11100100` (integer: 228)\n  WHEN the flags to be unset are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `0b00100100` (integer: 36)\n\n  Example:\n  iex> BitFlags.unset_all(228, [64, 128])\n  36","ref":"BCUtils.BitFlags.html#unset_all/2"},{"type":"module","title":"BCUtils.ColorFuncs","doc":"This module is used to manipulate colors.\n  It offers a set of functions that can be used to \n  change the color of text in the terminal, using ANSI escape codes.\n  It covers all color combinations and effects supported by ANSI.","ref":"BCUtils.ColorFuncs.html"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.black_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#black_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.blue_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#blue_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_black_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_black_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_blue_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_blue_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_cyan_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_cyan_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_green_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_green_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_magenta_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_magenta_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_red_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_red_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_white_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_white_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.bright_yellow_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#bright_yellow_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.cyan_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#cyan_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.green_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#green_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.magenta_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#magenta_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.red_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#red_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.reset/0","doc":"","ref":"BCUtils.ColorFuncs.html#reset/0"},{"type":"function","title":"BCUtils.ColorFuncs.tui/3","doc":"","ref":"BCUtils.ColorFuncs.html#tui/3"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.white_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#white_on_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_bright_black/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_bright_black/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_bright_blue/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_bright_blue/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_bright_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_bright_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_bright_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_bright_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_bright_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_bright_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_bright_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_bright_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_bright_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_bright_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_bright_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_bright_yellow/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_cyan/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_cyan/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_green/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_green/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_magenta/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_magenta/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_red/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_red/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_white/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_white/0"},{"type":"function","title":"BCUtils.ColorFuncs.yellow_on_yellow/0","doc":"","ref":"BCUtils.ColorFuncs.html#yellow_on_yellow/0"},{"type":"extras","title":"Getting Started","doc":"# Getting Started with BCUtils","ref":"getting-started.html"},{"type":"extras","title":"Description - Getting Started","doc":"BCUtils is a collection of utilities and novelty helpers for BEAM Campus projects.","ref":"getting-started.html#description"},{"type":"extras","title":"Installation - Getting Started","doc":"in your `mix.exs` file:\n\n```elixir\n\ndef deps do\n  [\n    {:bc_utils, \"~> 0.1.0\"}\n  ]\nend\n\n```","ref":"getting-started.html#installation"},{"type":"extras","title":"Read Me","doc":"# BCUtils\n\nBCUtils (Beam Campus Utils) is a collection of utilities and novelty helpers for Elixir projects.","ref":"readme.html"},{"type":"extras","title":"Installation - Read Me","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `bc_utils` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:bc_utils, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"- Initial release\n- introduced BCUtils.Banner","ref":"changelog.html#v0-1-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}